      SUBROUTINE LGRNGX (AU, NA, AC)
C     ******************************************************************
C     FORTRAN SUBROUTINE FOR LAGRANGIAN POLYNOMIAL EXPANSION
C     ******************************************************************
C     AU = COORDINATE ARGUMENTS    (N-ARRAY)
C     NA = NUMBER OF ARGUMENTS     (N)
C     AC = POLYNOMIAL COEFFICIENTS (NX(N+1) ARRAY)
C
      DIMENSION AU(1), AC(2)
  001 DO 003 I=1,NA
      K=(I-1)*NA
      L=K+I
      AC(L)=1.0
      SM=0.0
      DO 002 J=1,I
      K=K+1
      L=K+NA
      AC(L)=SM-AU(I)*AC(K)
      SM=AC(K)
  002 CONTINUE
  003 CONTINUE
      DO 005 I=1,NA
      K=NA+NA*NA
      L=I*NA
      AC(L)=1.0
      DO 004 J=2,NA
      SM=AU(I)*AC(L)
      L=L-1
      AC(L)=SM+AC(K)
      K=K-1
  004 CONTINUE
  005 CONTINUE
      DO 008 I=1,NA
      TM=1.0
      DO 006 J=1,NA
      IF(J.EQ.I)GO TO 006
      TD=AU(I)-AU(J)
      TM=TM*TD
  006 CONTINUE
      K=(I-1)*NA
      DO 007 J=1,NA
      K=K+1
      AC(K)=AC(K)/TM
  007 CONTINUE
  008 CONTINUE
      RETURN
      END
